@@ -102,7 +102,7 @@ fmts_text [] = {
 
 /* Note: there is no entry for GO_FORMAT_UNKNOWN.  */
 char const * const * const
-go_format_builtins[] = {
+_go_format_builtins[] = {
 	fmts_general,
 	fmts_number,
 	fmts_currency,
@@ -133,7 +133,7 @@ add_dt_format (GHashTable *dt_hash, gboolean timep, guint *N, const char *fmt)
 	(timep ? fmts_time : fmts_date)[*N] = fmt2;
 	g_hash_table_insert (dt_hash, fmt2, fmt2);
 	(*N)++;
-	(timep ? fmts_time : fmts_date)[*N] = NULL;	
+	(timep ? fmts_time : fmts_date)[*N] = NULL;
 }
 
 static void
@@ -194,7 +194,7 @@ guess_date_sep (void)
 }
 
 void
-go_currency_date_format_init (void)
+_go_currency_date_format_init (void)
 {
 	GOFormatCurrency const *currency = go_format_locale_currency ();
 	GHashTable *dt_hash;
@@ -265,12 +265,14 @@ go_currency_date_format_init (void)
 	add_dt_format (dt_hash, FALSE, &N, "dd/mm/yyyy");
 	add_dt_format (dt_hash, FALSE, &N, "dd/mm/yy");
 	add_dt_format (dt_hash, FALSE, &N, "d-mmm-yyyy");
+	add_dt_format (dt_hash, FALSE, &N, "yyyy-mm-dd");
 
 	fmt = go_format_new_magic (GO_FORMAT_MAGIC_SHORT_DATETIME);
 	if (fmt) {
 		add_dt_format (dt_hash, FALSE, &N, go_format_as_XL (fmt));
 		go_format_unref (fmt);
 	}
+	add_dt_format (dt_hash, FALSE, &N, "yyyy-mm-dd hh:mm:ss");
 
 	g_hash_table_destroy (dt_hash);
 
@@ -313,7 +315,7 @@ go_currency_date_format_init (void)
 }
 
 void
-go_currency_date_format_shutdown (void)
+_go_currency_date_format_shutdown (void)
 {
 	/* We need to free allocated strings since */
 	/* currency_date_format_init/shutdown may  */
@@ -343,7 +345,7 @@ go_currency_date_format_shutdown (void)
 	}
 }
 
-GOFormatCurrency const go_format_currencies[] =
+GOFormatCurrency const _go_format_currencies[] =
 {
  	{ "", N_("None"), TRUE, FALSE },	/* These first six elements */
  	{ "$", "$", TRUE, FALSE },		/* Must stay in this order */
